<?php

/**
 * libphonenumber-for-php-lite data file
 * This file has been @generated from libphonenumber data
 * Do not modify!
 * @internal
 */

return [
    'id' => 'AC',
    'countryCode' => 247,
    'generalDesc' => [
        'pattern' => '(?:[01589]\\d|[46])\\d{4}',
        'posLength' => [
            5,
            6,
        ],
    ],
    'fixedLine' => [
        'pattern' => '6[2-467]\\d{3}',
        'example' => '62889',
        'posLength' => [
            5,
        ],
    ],
    'mobile' => [
        'pattern' => '4\\d{4}',
        'example' => '40123',
        'posLength' => [
            5,
        ],
    ],
    'tollFree' => [
        'posLength' => [
            -1,
        ],
    ],
    'premiumRate' => [
        'posLength' => [
            -1,
        ],
    ],
    'sharedCost' => [
        'posLength' => [
            -1,
        ],
    ],
    'personalNumber' => [
        'posLength' => [
            -1,
        ],
    ],
    'voip' => [
        'posLength' => [
            -1,
        ],
    ],
    'pager' => [
        'posLength' => [
            -1,
        ],
    ],
    'uan' => [
        'pattern' => '(?:0[1-9]|[1589]\\d)\\d{4}',
        'example' => '542011',
        'posLength' => [
            6,
        ],
    ],
    'voicemail' => [
        'posLength' => [
            -1,
        ],
    ],
    'noInternationalDialling' => [
        'posLength' => [
            -1,
        ],
    ],
    'internationalPrefix' => '00',
    'numberFormat' => [],
];
